@@ -41,6 +41,50 @@
         <source>&amp;Delete</source>
         <translation>&amp;Borrar</translation>
     </message>
+    <message>
+        <source>Choose the address to send coins to</source>
+        <translation>Elija la direccion a donde se enviaran las monedas</translation>
+    </message>
+    <message>
+        <source>Choose the address to receive coins with</source>
+        <translation>Elija la dirección para recibir monedas.</translation>
+    </message>
+    <message>
+        <source>C&amp;hoose</source>
+        <translation>Elija</translation>
+    </message>
+    <message>
+        <source>Sending addresses</source>
+        <translation>Direcciones de Envio</translation>
+    </message>
+    <message>
+        <source>Receiving addresses</source>
+        <translation>Direcciones de recibo</translation>
+    </message>
+    <message>
+        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
+        <translation>Estas son tus direcciones de Bitcoin para enviar pagos. Siempre revisa el monto y la dirección de envío antes de enviar monedas.</translation>
+    </message>
+    <message>
+        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
+        <translation>Estas son sus direcciones de Bitcoin para recibir pagos. Se recomienda utilizar una nueva dirección de recepción para cada transacción.</translation>
+    </message>
+    <message>
+        <source>&amp;Copy Address</source>
+        <translation>&amp;Copiar dirección</translation>
+    </message>
+    <message>
+        <source>Copy &amp;Label</source>
+        <translation>copiar y etiquetar</translation>
+    </message>
+    <message>
+        <source>&amp;Edit</source>
+        <translation>Editar</translation>
+    </message>
+    <message>
+        <source>Export Address List</source>
+        <translation>Exportar lista de direcciones </translation>
+    </message>
     </context>
 <context>
     <name>AddressTableModel</name>
@@ -249,7 +293,7 @@
         <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
         <translation>La cartera esta &lt;b&gt;encriptada&lt;/b&gt; y &lt;b&gt;bloqueada&lt;/b&gt; actualmente </translation>
     </message>
-</context>
+    </context>
 <context>
     <name>CoinControlDialog</name>
     <message>
@@ -264,10 +308,6 @@
         <source>Amount:</source>
         <translation>Monto:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioridad:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Cuota:</translation>
@@ -292,10 +332,6 @@
         <source>Confirmed</source>
         <translation>Confirmado </translation>
     </message>
-    <message>
-        <source>Priority</source>
-        <translation>Prioridad</translation>
-    </message>
     </context>
 <context>
     <name>EditAddressDialog</name>
@@ -344,11 +380,22 @@
     </context>
 <context>
     <name>Intro</name>
+    <message>
+        <source>Bitcoin</source>
+        <translation>Bitcoin</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     </context>
+<context>
+    <name>ModalOverlay</name>
+    <message>
+        <source>Form</source>
+        <translation>Formulario</translation>
+    </message>
+    </context>
 <context>
     <name>OpenURIDialog</name>
     </context>
@@ -370,6 +417,10 @@
         <source>none</source>
         <translation>Ninguno </translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Error</translation>
+    </message>
     </context>
 <context>
     <name>OverviewPage</name>
@@ -390,6 +441,13 @@
         <source>Amount</source>
         <translation>Monto</translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation>desconocido</translation>
+    </message>
+</context>
+<context>
+    <name>QObject::QObject</name>
     </context>
 <context>
     <name>QRImageWidget</name>
@@ -456,10 +514,6 @@
         <source>Amount:</source>
         <translation>Monto:</translation>
     </message>
-    <message>
-        <source>Priority:</source>
-        <translation>Prioridad:</translation>
-    </message>
     <message>
         <source>Fee:</source>
         <translation>Cuota:</translation>
@@ -472,10 +526,6 @@
         <source>Change:</source>
         <translation>Cambio</translation>
     </message>
-    <message>
-        <source>fast</source>
-        <translation>rápido</translation>
-    </message>
     <message>
         <source>Send to multiple recipients at once</source>
         <translation>Enviar a múltiples receptores a la vez</translation>
@@ -591,9 +641,17 @@
     </context>
 <context>
     <name>WalletModel</name>
+    <message>
+        <source>Send Coins</source>
+        <translation>Enviar monedas</translation>
+    </message>
     </context>
 <context>
     <name>WalletView</name>
+    <message>
+        <source>Export the data in the current tab to a file</source>
+        <translation>Exportar la información en la pestaña actual a un archivo</translation>
+    </message>
     </context>
 <context>
     <name>bitcoin-core</name>
@@ -613,10 +671,6 @@
         <source>Verifying blocks...</source>
         <translation>Verificando bloques...</translation>
     </message>
-    <message>
-        <source>Verifying wallet...</source>
-        <translation>Verificando cartera...</translation>
-    </message>
     <message>
         <source>Wallet options:</source>
         <translation>Opciones de cartera:</translation>
@@ -629,10 +683,6 @@
         <source>Warning</source>
         <translation>Aviso</translation>
     </message>
-    <message>
-        <source>Loading addresses...</source>
-        <translation>Cargando direcciones...</translation>
-    </message>
     <message>
         <source>Loading block index...</source>
         <translation>Cargando indice de bloques... </translation>
