@@ -3,7 +3,7 @@
     <name>AddressBookPage</name>
     <message>
         <source>Right-click to edit address or label</source>
-        <translation>Spustelėkite dešinįjį klaviša norint keisti adresą arba etiketę</translation>
+        <translation>Spustelėkite dešinįjį klavišą norint keisti adresą arba etiketę</translation>
     </message>
     <message>
         <source>Create a new address</source>
@@ -44,6 +44,10 @@
     </context>
 <context>
     <name>AddressTableModel</name>
+    <message>
+        <source>Address</source>
+        <translation>Adresas</translation>
+    </message>
     </context>
 <context>
     <name>AskPassphraseDialog</name>
@@ -113,6 +117,10 @@
         <source>&amp;About %1</source>
         <translation>&amp;Apie %1</translation>
     </message>
+    <message>
+        <source>Show information about %1</source>
+        <translation>Rodyti informaciją apie %1</translation>
+    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Apie &amp;Qt</translation>
@@ -245,6 +253,12 @@
         <source>Catching up...</source>
         <translation>Vejamasi...</translation>
     </message>
+    <message>
+        <source>Date: %1
+</source>
+        <translation>Data: %1
+</translation>
+    </message>
     <message>
         <source>Sent transaction</source>
         <translation>Sandoris nusiųstas</translation>
@@ -368,6 +382,10 @@
         <source>Welcome</source>
         <translation>Sveiki</translation>
     </message>
+    <message>
+        <source>Bitcoin</source>
+        <translation>Bitcoin</translation>
+    </message>
     <message>
         <source>Error</source>
         <translation>Klaida</translation>
@@ -505,6 +523,10 @@
         <source>Client restart required to activate changes.</source>
         <translation>Kliento perkrovimas reikalingas nustatymų aktyvavimui</translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation>Klaida</translation>
+    </message>
     <message>
         <source>This change would require a client restart.</source>
         <translation>Šis pakeitimas reikalautų kliento perkrovimo</translation>
@@ -550,7 +572,11 @@
     </context>
 <context>
     <name>PeerTableModel</name>
-    </context>
+    <message>
+        <source>Received</source>
+        <translation>Gauta</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -569,7 +595,27 @@
         <source>N/A</source>
         <translation>nėra</translation>
     </message>
-    </context>
+    <message>
+        <source>%1 B</source>
+        <translation>%1 B</translation>
+    </message>
+    <message>
+        <source>%1 KB</source>
+        <translation>%1 KB</translation>
+    </message>
+    <message>
+        <source>%1 MB</source>
+        <translation>%1 MB</translation>
+    </message>
+    <message>
+        <source>%1 GB</source>
+        <translation>%1 GB</translation>
+    </message>
+    <message>
+        <source>unknown</source>
+        <translation>nežinomas</translation>
+    </message>
+</context>
 <context>
     <name>QObject::QObject</name>
     </context>
@@ -642,10 +688,6 @@
         <source>&amp;Console</source>
         <translation>&amp;Konsolė</translation>
     </message>
-    <message>
-        <source>&amp;Clear</source>
-        <translation>Išvalyti</translation>
-    </message>
     <message>
         <source>Totals</source>
         <translation>Viso:</translation>
@@ -658,22 +700,6 @@
         <source>Clear console</source>
         <translation>Išvalyti konsolę</translation>
     </message>
-    <message>
-        <source>%1 B</source>
-        <translation>%1 B</translation>
-    </message>
-    <message>
-        <source>%1 KB</source>
-        <translation>%1 KB</translation>
-    </message>
-    <message>
-        <source>%1 MB</source>
-        <translation>%1 MB</translation>
-    </message>
-    <message>
-        <source>%1 GB</source>
-        <translation>%1 GB</translation>
-    </message>
     <message>
         <source>never</source>
         <translation>Niekada</translation>
@@ -716,6 +742,10 @@
         <source>Copy &amp;Address</source>
         <translation>&amp;Kopijuoti adresą</translation>
     </message>
+    <message>
+        <source>Address</source>
+        <translation>Adresas</translation>
+    </message>
     </context>
 <context>
     <name>RecentRequestsTableModel</name>
@@ -900,6 +930,10 @@
     </context>
 <context>
     <name>TransactionView</name>
+    <message>
+        <source>Address</source>
+        <translation>Adresas</translation>
+    </message>
     </context>
 <context>
     <name>UnitDisplayStatusBarControl</name>
@@ -947,10 +981,6 @@
         <source>Verifying blocks...</source>
         <translation>Tikrinami blokai...</translation>
     </message>
-    <message>
-        <source>Verifying wallet...</source>
-        <translation>Tikrinama piniginė...</translation>
-    </message>
     <message>
         <source>Information</source>
         <translation>Informacija</translation>
@@ -975,14 +1005,6 @@
         <source>Allow DNS lookups for -addnode, -seednode and -connect</source>
         <translation>Leisti DNS paiešką sujungimui ir mazgo pridėjimui</translation>
     </message>
-    <message>
-        <source>Loading addresses...</source>
-        <translation>Užkraunami adresai...</translation>
-    </message>
-    <message>
-        <source>Invalid -proxy address: '%s'</source>
-        <translation>Neteisingas proxy adresas: '%s'</translation>
-    </message>
     <message>
         <source>Insufficient funds</source>
         <translation>Nepakanka lėšų</translation>
@@ -991,18 +1013,10 @@
         <source>Loading block index...</source>
         <translation>Įkeliamas blokų indeksas...</translation>
     </message>
-    <message>
-        <source>Add a node to connect to and attempt to keep the connection open</source>
-        <translation>Pridėti mazgą prie sujungti su and attempt to keep the connection open</translation>
-    </message>
     <message>
         <source>Loading wallet...</source>
         <translation>Užkraunama piniginė...</translation>
     </message>
-    <message>
-        <source>Cannot write default address</source>
-        <translation>Negalima parašyti įprasto adreso</translation>
-    </message>
     <message>
         <source>Rescanning...</source>
         <translation>Peržiūra</translation>
