@@ -1,5 +1,9 @@
-#ifndef QVALUECOMBOBOX_H
-#define QVALUECOMBOBOX_H
+// Copyright (c) 2011-2015 The Bitcoin Core developers
+// Distributed under the MIT software license, see the accompanying
+// file COPYING or http://www.opensource.org/licenses/mit-license.php.
+
+#ifndef BITCOIN_QT_QVALUECOMBOBOX_H
+#define BITCOIN_QT_QVALUECOMBOBOX_H
 
 #include <QComboBox>
 #include <QVariant>
@@ -8,7 +12,9 @@
 class QValueComboBox : public QComboBox
 {
     Q_OBJECT
+
     Q_PROPERTY(QVariant value READ value WRITE setValue NOTIFY valueChanged USER true)
+
 public:
     explicit QValueComboBox(QWidget *parent = 0);
 
@@ -18,16 +24,14 @@ public:
     /** Specify model role to use as ordinal value (defaults to Qt::UserRole) */
     void setRole(int role);
 
-signals:
+Q_SIGNALS:
     void valueChanged();
 
-public slots:
-
 private:
     int role;
 
-private slots:
+private Q_SLOTS:
     void handleSelectionChanged(int idx);
 };
 
-#endif // QVALUECOMBOBOX_H
+#endif // BITCOIN_QT_QVALUECOMBOBOX_H
